==> jc-1.4.0.tar.gz: soot/jimple/toolkits/invoke/ThrowManager.h <==
// public class soot.jimple.toolkits.invoke.ThrowManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 407f579f1feba456 soot_jimple_toolkits_invoke_ThrowManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_ThrowManager_H_
#define _JC_soot_jimple_toolkits_invoke_ThrowManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_jimple_JimpleBody$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_refs	_jc_soot_jimple_toolkits_invoke_ThrowManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_ThrowManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$refs	_jc_soot_jimple_toolkits_invoke_ThrowManager$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$nonrefs	_jc_soot_jimple_toolkits_invoke_ThrowManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$object	_jc_soot_jimple_toolkits_invoke_ThrowManager$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vmethods	_jc_soot_jimple_toolkits_invoke_ThrowManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vtable	_jc_soot_jimple_toolkits_invoke_ThrowManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vtype	_jc_soot_jimple_toolkits_invoke_ThrowManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_ThrowManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_ThrowManager$object *);

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_invoke_ThrowManager$method$addThrowAfter$6833159785a1d62f(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_invoke_ThrowManager$method$getNullPointerExceptionThrower$eb0231db4e1fdc73(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);
extern jboolean _jc_soot_jimple_toolkits_invoke_ThrowManager$method$isExceptionCaughtAt$90ec9d12708bee71(_jc_env *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_soot_Body$object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_ThrowManager$vmethods	soot_jimple_toolkits_invoke_ThrowManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_ThrowManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$refs {
    _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_refs	soot_jimple_toolkits_invoke_ThrowManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_nonrefs	soot_jimple_toolkits_invoke_ThrowManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$object {
	_jc_soot_jimple_toolkits_invoke_ThrowManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_ThrowManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_ThrowManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_ThrowManager$vtype _jc_soot_jimple_toolkits_invoke_ThrowManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_ThrowManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_ThrowManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_ThrowManager_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/invoke/ThrowManager.h <==
// public class soot.jimple.toolkits.invoke.ThrowManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 407f579f1feba456 soot_jimple_toolkits_invoke_ThrowManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_ThrowManager_H_
#define _JC_soot_jimple_toolkits_invoke_ThrowManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_jimple_JimpleBody$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_refs	_jc_soot_jimple_toolkits_invoke_ThrowManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_ThrowManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$refs	_jc_soot_jimple_toolkits_invoke_ThrowManager$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$nonrefs	_jc_soot_jimple_toolkits_invoke_ThrowManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_ThrowManager$object	_jc_soot_jimple_toolkits_invoke_ThrowManager$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vmethods	_jc_soot_jimple_toolkits_invoke_ThrowManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vtable	_jc_soot_jimple_toolkits_invoke_ThrowManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vtype	_jc_soot_jimple_toolkits_invoke_ThrowManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_ThrowManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_ThrowManager$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_invoke_ThrowManager$method$addThrowAfter$6833159785a1d62f(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_invoke_ThrowManager$method$getNullPointerExceptionThrower$eb0231db4e1fdc73(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_invoke_ThrowManager$method$isExceptionCaughtAt$90ec9d12708bee71(_jc_env *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_ThrowManager$vmethods	soot_jimple_toolkits_invoke_ThrowManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_ThrowManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$refs {
    _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_refs	soot_jimple_toolkits_invoke_ThrowManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_ThrowManager$sub_nonrefs	soot_jimple_toolkits_invoke_ThrowManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_ThrowManager$object {
	_jc_soot_jimple_toolkits_invoke_ThrowManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_ThrowManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_ThrowManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_ThrowManager$vtype _jc_soot_jimple_toolkits_invoke_ThrowManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_ThrowManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_ThrowManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_ThrowManager_H_ */
